===============
Tables and text
===============

.. toctree::
   :maxdepth: 2

   GalleryTables.rst
   GalleryMatrices.rst
   GalleryConfig.rst
   GalleryStatus.rst
   GalleryDebug.rst
   GalleryDataframe.rst
   GalleryLegends.rst
   GalleryOptions.rst
